Accepts a comma separated list of valid nps (or nps partner) email addresses and adds the people specified via email address as an editors (formerly "owners") of the specified DataStore reference. Use the email address not the upn/username, e.g. first_last@nps.gov not FMLast@npsg.gov.
add_editors(reference_id, editor_list, dev = TRUE)NULL (invisibly)
if (FALSE) { # \dontrun{
add_editors(reference_id = 1234567,
editor_list = "john_doe@nps.gov")
} # }