The function Initiates an API call to datastore to make sure that a project is valid. Potential reasons for check to fail with an error include: The reference ID number does not go to a valid DataStore reference, the valid reference is not a Project type reference, the user not being on the VPN/on an NPS network, the project may not be public, the project may not be active, or the user may not have permissions to access or edit the project.

check_projects_valid(
  path = getwd(),
  filename = "DSbulkUploadR_input.xlsx",
  sheet_name,
  dev = TRUE
)

Arguments

path

String. Path to the file. Defaults to the current working directory.

filename

String. Input file to check. Defaults to "DSbulkdUploadR_input.xlsx"

sheet_name

String. Name of the excel sheet to check.

dev

Logical. Whether or not the API calls should be made to the development (TRUE) or production (FALSE) server. Defaults to TRUE.

Value

NULL (invisibly)

Examples

if (FALSE) { # \dontrun{
check_projects_valid(sheet_name = "Script")
} # }